@@ -26,7 +26,7 @@
 #include <KSharedConfig>
 
 #include "config.h"
-#ifdef HAVE_KACTIVITIES
+#if HAVE_KACTIVITIES
 #include <KActivities/Consumer>
 #endif
 
@@ -39,6 +39,7 @@
 #endif
 
 #include "dbusrunner_p.h"
+#include "kpluginmetadata_utils_p.h"
 #include "krunner_debug.h"
 #include "querymatch.h"
 #include "runnerjobs_p.h"
@@ -128,7 +129,7 @@ public:
 #if KRUNNER_BUILD_DEPRECATED_SINCE(5, 76)
         enabledCategories = stateData.readEntry("enabledCategories", QStringList());
 #endif
-#ifdef HAVE_KACTIVITIES
+#if HAVE_KACTIVITIES
         // Wait for consumer to be ready
         QObject::connect(&activitiesConsumer,
                          &KActivities::Consumer::serviceStatusChanged,
@@ -434,7 +435,7 @@ public:
 
     inline QString getActivityKey()
     {
-#ifdef HAVE_KACTIVITIES
+#if HAVE_KACTIVITIES
         if (activityAware) {
             const QString currentActivity = activitiesConsumer.currentActivity();
             return currentActivity.isEmpty() ? nulluuid : currentActivity;
@@ -471,7 +472,7 @@ public:
         stateData.sync();
     }
 
-#ifdef HAVE_KACTIVITIES
+#if HAVE_KACTIVITIES
     void deleteHistoryOfDeletedActivities()
     {
         KConfigGroup historyGroup = stateData.group("History");
@@ -526,7 +527,7 @@ public:
     KSharedConfigPtr configPrt;
     KConfigGroup stateData;
     QSet<QString> disabledRunnerIds; // Runners that are disabled but were loaded as single runners
-#ifdef HAVE_KACTIVITIES
+#if HAVE_KACTIVITIES
     const KActivities::Consumer activitiesConsumer;
 #endif
 };
@@ -820,7 +821,7 @@ QVector<KPluginMetaData> RunnerManager::runnerMetaDataList(const QString &parent
         QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("krunner/dbusplugins"), QStandardPaths::LocateDirectory);
     const QStringList dbusRunnerFiles = KFileUtils::findAllUniqueFiles(dBusPlugindirs, QStringList(QStringLiteral("*.desktop")));
     for (const QString &dbusRunnerFile : dbusRunnerFiles) {
-        KPluginMetaData pluginMetaData = KPluginMetaData::fromDesktopFile(dbusRunnerFile, QStringList(QStringLiteral("plasma-runner.desktop")));
+        KPluginMetaData pluginMetaData = parseMetaDataFromDesktopFile(dbusRunnerFile);
         if (pluginMetaData.isValid() && !knownRunnerIds.contains(pluginMetaData.pluginId())) {
             pluginMetaDatas.append(pluginMetaData);
             knownRunnerIds.insert(pluginMetaData.pluginId());
@@ -863,7 +864,7 @@ QVector<KPluginMetaData> RunnerManager::runnerMetaDataList()
         QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("krunner/dbusplugins"), QStandardPaths::LocateDirectory);
     const QStringList dbusRunnerFiles = KFileUtils::findAllUniqueFiles(dBusPlugindirs, QStringList(QStringLiteral("*.desktop")));
     for (const QString &dbusRunnerFile : dbusRunnerFiles) {
-        KPluginMetaData pluginMetaData = KPluginMetaData::fromDesktopFile(dbusRunnerFile, QStringList(QStringLiteral("plasma-runner.desktop")));
+        KPluginMetaData pluginMetaData = parseMetaDataFromDesktopFile(dbusRunnerFile);
         if (pluginMetaData.isValid() && !knownRunnerIds.contains(pluginMetaData.pluginId())) {
             pluginMetaDatas.append(pluginMetaData);
             knownRunnerIds.insert(pluginMetaData.pluginId());
@@ -1066,6 +1067,11 @@ void RunnerManager::reset()
     Q_EMIT queryFinished();
 }
 
+KPluginMetaData RunnerManager::convertDBusRunnerToJson(const QString &filename) const
+{
+    return parseMetaDataFromDesktopFile(filename);
+}
+
 void RunnerManager::enableKNotifyPluginWatcher()
 {
     if (!d->watcher) {
